@@ -121,7 +121,7 @@ def main(sysargs=None):
     msg = "### Running 'git bloom-import-upstream --replace'... "
     info(msg)
     info("###")
-    ret = iu_main(['--replace'])
+    ret = iu_main(['--replace', '-d' if args.debug else ''])
     msg += "returned (" + str(ret) + ")"
     if ret > 0:
         error(msg)
@@ -180,5 +180,5 @@ def main(sysargs=None):
     info(ansi('greenf') + ansi('boldon') + "Everything went as expected, "
          "you should check that the new tags match your expectations, and "
          "then push to the release repo with:" + ansi('reset'))
-    info("  git push --all && git push --tags")
+    info("  git push --all && git push --tags  # You might have to add --force to the second command if you are over-writing existing flags")
     return 0
